
# q-expansion of newform 64.22.a.i, downloaded from the LMFDB on 16 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 64
weight = 22
poly_data = [-540, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0], 1], [[-2688, 5376], 1]]

hecke_ring_character_values = None
aps_data = [[0, 0], [-32820, -1], [-6844662, -204], [-130254040, -5886], [-72717981660, 314445], [-714450208670, 324756], [920310288210, -84858072], [8390371964284, -265449285], [-159845962713480, -627682938], [-1871055887883246, 4723712580], [56021176731296, -4595859000], [16681352818773610, 245612021796], [87564872161566666, -265794737520], [-7673306708264060, 1278047140965], [-342424409644227600, -553734430452], [-337652697122210790, 7229502808932], [-521222625217717452, -7341605116095], [-4532998914868234382, 32044341559860], [15232150523401387660, -19726418252529], [-4099546751415259032, -115464309246510], [12707543329687396970, 226051490503944], [60602176612530082448, -99610802523180], [-54371468378516904900, 218924689501323], [-92103999637482684486, 1052618322986760], [369748892594238233570, 5190622720371144], [-809642748793775923926, 6827670331694340], [-1284664742823851359480, 1814160452030298], [-185173432736290815420, -19603001793940683], [117945604173606763138, -30487068201076380], [5406227775077409667890, -4770621079060032], [-11494768356732407735680, 14009304202779744], [-9834148295109877732020, 112162290729860415], [23824062179806956993450, 208014138773138256], [-18914021116472704326236, 82943137520235405], [-16944283285957670559174, -335845665467080140], [-45602968271543417683720, 202926997511320230], [72223332925937010485650, 916749635512223124], [-78702587547744575112020, -792337643846017065], [-153227197838487476938680, -1226132296269518934], [6489810450984260200770, 201649749141733812], [428432838768733369223772, 1710303908815063155], [-175118449305317804400230, -5818498590609511020], [-344063629133270719244352, 8865056747083828080], [368913831158629112814530, -1753564317786181368], [420187570165408937433930, -6938604196181116716], [448161328339841711766248, -4604252715466321230], [-2135747583304657721458244, -9121672761864408405], [-3245286469898479962251680, 9469339777024350840], [-7517439275389945237271700, -26264875608200337273], [-2496435818924888949435734, 32629117504328480340], [5143786237437345425087370, 49477719279571604808], [-9479704180320260200797264, -29132156026783538820], [-4826960001269720337653326, -69433802892651084120], [-27809942420366204487209100, 6864450375709383825], [17607366150463869122123010, -152995352321258883072], [10387560333116078220554280, 226759940483249141634], [6619650547177343685032802, -1914655417769666940], [-3605715351913729469253040, -108562602363611992380], [25620000200217494630205370, 114400582920892544868], [26646618478743808355870586, 214646774974275742440], [31704300842540291821664980, 251438249230164780777], [47138491612552736382742890, 554411918320525557780], [49834395252163743480272860, -405317433517997153229], [-15591750497062260764600808, 908613523768327883790], [-95686299381511344909620710, 510629395735642983696], [27461374705751662276225650, 918678773004865226052], [-187812458765882406540920348, 2901542050757476291005], [-29997189700455398449287790, -681670213630678237536], [116602912732281867075506580, -2383911398013908279175], [280187324997561902515344850, -1200876131500471449180], [-563822858127247860733520670, -1271483900507003803104], [509872606801296575810000904, -6125953003325755646310], [901707406773496402088371760, 3446203709071136846556], [1074198005795831712511047130, 975440525819239396548], [1279994303780098370954026228, 5128428313044405925425], [-1441840712618086236971487360, 5102948876388438283872], [-1706694790047966462417514614, -5980084076515094412060], [-246732354467675891629049630, 6609676711509745842276], [3372267293966892533954588370, 1300512546268399444200], [794593137889189745525530106, 16064831549582584445520], [361401078744187069423208364, 17912680017540019449975], [2347668983552127782883950314, 5829039183358134354420], [-3065567617710270323020016784, 35632690603343079229740], [-2527977926298161322771660430, -19787903644628250066456], [1515497330228073636260683928, -10273405031808278945490], [-1535836405998410673540721740, -66325980052371955440447], [-5052230989464416372952894, -27677625438584552974200], [1156969649529829030471613930, 55897167318106080650832], [-4071863996710436833131831390, -106740576799550302734780], [-1300683768128535656598396400, 104276054926112619777588], [16485985927799725820922145980, 32523323921830605499275], [-15676515593387170579166588064, -1299507315910662440520], [7107432042322989905768456840, 57761547493912467888762], [9920170218265727268534639300, -37262460108911048150475], [4508415220166891994326148124, 127033784194143836353635], [18752324673167726944357557720, -152554759504294202767746], [-1497796343102709273543575886, -86560247858743053114540], [7954798333343027045305412394, 63827958966577204054800], [-19426472333352735108570907100, -33023805070381561480563], [50130332445931875743766266386, -223380932718772533127500], [68813943503043016185618457900, 204232860289354967210583], [-21817328191169510087967374910, -18996531035352960208620], [34466485182558577280627233500, -625354738929590346035469], [-15379232081261712869237924070, -621733102998385731586800], [17998485862765880669537706292, -755459725453606231646175], [14387999940707430079105597250, -856661008628370208441824], [27720970039165859308406879460, 769272813524172772272957], [-39899354389425707895488400750, 122458536139483858472256], [-7078274207309652825704053320, 768088373834167154946390], [46380484914686255900371069370, -1079454649393886288000760], [188089249561281521612303840, 296960785459831058316696], [-4312639058618377783540827350, 1109579347536526177638516], [-144502039797273628323684762870, 1577806689862530160312488], [-138971356865327961971860154300, -98090387606309570946315], [82392278925179459762523910232, -24492087480488619561570], [121151880861188176319269978242, -1668798896546787138820920], [-335064349850277174968394398900, -869034367161447247526913], [69320492955922659353027473320, 1682530498589760788335074], [442349958047811256305052492770, -1264750273324022100486204], [-7605698802240610651737212676, -4241622287628715225776645], [-247928148692107184831774693318, 1585638779292503854466580], [-619596082674693511797563512030, 838192440034492433240328], [-590765443510191496824966798870, -2966694182849590801695516], [-563645144462252962225346593020, 1832454819683452141988229], [103099143055265021523773603932, 7273868938570174222052595], [127498537496330674826888125170, -5386096615662981447264780], [600288425233596769202014480714, -4801285013699013027765660], [183098974600758960908793747216, 4008668164500722000869620], [969007969170506707149046616120, -3634346445981514812835722], [942634194254948378347792977490, -1886343164369014990754556], [-1261565426110874874334038195860, 3794993732119298867810055], [-498460321738312097816250747000, -7747879718206541065564998], [361993009769912365164795106736, 8877900259488596999281020], [-561275004582724965113490352550, 12361167490271446782673524], [-1254027129996588424348604197158, -2748154419173212599049200], [817103872172230917229789981442, -14222926409777860057618680], [359480321289377507424810936330, -7742290487575438881006300], [91764589507496692225714361980, -3369526023178553677979877], [297272596701829354116261334290, -7836831981657087220316844], [877768393771845876761320750794, -4026147380628074651324400], [227526647031333268957204839556, 5047425600837129194434245], [3813912731143524965345865710874, 28040751513295391510411460], [2843384165725510920532981661720, 13932672479304840931499406], [1659295248876598393932513287220, 5412663798063834863181345], [1277496660429512929272822790258, -34654380690853813550795820], [6595650422122262728899429453672, 21371558558776288948320210], [-3243567127128735511899861578630, 46204962945530649541545060], [3180208551424480115414252604090, -37740394780171860986304624], [1384420369570939816327893993364, 42403426769616636878634105], [6348751964547288761787761967840, -55465399027931159443988328], [7268713305958490385490158508930, -48646329327138876107285052], [-4949296964094780474743745770958, 78225040427058514571506080], [-6057319731797899872879392101220, -45107920365593829735612573], [-6748589670230604746701800233640, -82537470272651248360230114], [3844359798648967132594292266660, -38342686245160254653272563], [-1156562198715758413846672032048, 167479805883660625186882020], [8005662526834222587836360998904, 43505238245481423672782310], [-2379983616187153976788204650462, 129420252246470807313212040], [1759038852848076961566510402890, 61272462951746219322359496], [22626036986730227018783616901698, 34713868002814906117989540], [-2335925485297112173776704582820, -64597382301568897894159341], [6315189344522171327423771127450, -51534781352921640418485552], [30779663846336320311036788324840, 47222452826515867657717746], [-3803104601699891949346048627356, 204346225187348361070879485], [-21580313754043075778035435934190, -59292967691744722843439064], [-23389355856829500297636488420040, 57642426585627241135249974], [14761380022021656176170044120416, -221813621697460104705308040], [33781119186694349004965128805290, 145931291153549105642736228], [28659941879560630406632160469170, 126266326582862294985470760], [-21643061741866626896873467641510, 15650869742220648532870164], [32683649933662925567120637350004, -171716570055781412141615055], [19178877753756173852855565862066, -21935994007060853967007260], [45827250391937847853587568324392, -131647498888433550563861310], [-44234402475092457291810641020630, 91613237205832859700163944], [13478917886292341165963723921744, 269700387541104406064043780], [47770121862363482632903876626042, 372235668324304107550161000], [4004542721408925536286191655892, -681867991770854937667133175], [-30720921087575788342478491194774, 177551265530097028362883140], [-31599348501476679351024909008440, -147147372294215970785017590], [100596943763637716570459075708866, 133904684898854563480073460], [2620020905960367367216519680320, -959878942658204905320513264], [23010647682508475116255022889612, 203345655940148709520844655], [6623893432012823780016427661770, 232074707652686655846967284], [65167359127695645124368564176490, 92272278356721505120147560], [17635416055843120484964181526160, 45032631911857619908871316], [-33913586664509720490407890763910, 323847807450214862714110260], [-34693985955316120823017206755630, -4642306393182735067603308], [157549781030868325496199312652780, -218373976482100450788136473], [70623788703373390334983084425482, -281595340548954633089813040], [-117710342300875633496620505002368, -655134198529308276471606240], [195865464176476363848519856606850, -290779929178236544853411424], [11118546676291699512098817577380, 1583940632070466489446713997], [-77454585253413010476484384112900, 1549139613655596121217377755], [62550780269292071014252870991250, 117564554650483985040045060], [-110830346164641934234914209339220, -874363257798493569099333033], [-146845821377169692689850494528950, -849397595667497745467819352], [-51520458840760530983600926858126, 125714509763902243793801280], [6057148488635371286005249507570, -401538765211173702143985132], [-131771120410712070670293185379390, 1704647290600682271616494720], [17012027543436188153176180141800, -332284441556217231247960590], [-83514077575085814457146558363486, 3095238660026566523058111060], [-331491827792506892417470102241008, -461756470414699468896275340], [331765570377903829847598893061370, 431557200978739703075223684], [67276496695360581645987014585954, -213346571832085413640896000], [-278298858466456298989950394721340, -2276587889402928122782590315], [117338483363272640204191834841010, 259923798970967222510220132], [-318384269398549539196507992602368, -2418645490897188756616286400], [-337451631394325990812746726603060, -2231931676247565564414366465], [-171014198994256497289362556297686, 1927059075954680763438113160], [367150380278973562808132047499044, -1677037142541274405287973875], [-29729082144489723599390858381230, -4782600216021758780232738648], [-430232694861769325378898903114822, -2900391021621697099534640940], [-575248082596951584738183978369160, 2378771806059430630209207558], [-230209450052213483743249476188460, 3319931058184867667263037097], [-51898347621457085250968829782328, -2828413463228737507087479990], [-445436993291343706835115957081910, -907466261762265681928633200], [762578650852353212232539763461360, 1289084071414249376643533580], [364106488559885736096570126929298, 1552993036032763733945432040], [386084839974295190012836982260920, -1512957015198823622679494634], [213922087261701451037288776700370, -6092478183554040730892675196], [198129987650589526408812360604714, 9294241313890752236045094420], [388533826459739499812140284292952, -12027632657344593536937357090], [43242249341617057391523948969858, -6554641490756987587636772280], [-1189054549026747962615760860100400, 8902632919644706552782817572], [-1424202371306090193610620390811140, 207065499520558906665688923], [65691225121430189400696315158842, -15628233696878204979663089340], [-886622730802764451892631646247430, -6223356842739549426793755000], [-1374939141705236291907179522872800, -2073048653649578698978181400], [1568181170876968480251882097058120, -6490248075814259542002665814], [87190958957125186638402875617284, 6009250538778735386483209605], [-1025546508847000341967552671512510, 994902591256452570895763652], [45713569050051166809524597285212, 4168079129368429342295299155], [1557842859544926018307022362198208, 5039926782071577374303863920], [2290764366090487978443472902739434, -7483974897411924661923870360], [155682907086150818057622444860260, -15111268973464088173832762499], [-1107052109103444750086092433230320, -9663609308301593516017603020], [-1169395399579825971563937993312238, -15274272350859984726944169240], [-954023883906277806910369308678150, -8252620475357547847986713964], [-731557496467384830828798021182700, 11005126563147231367853801145], [-901465555976391309961005240633720, 5689447866552085240340706810], [512296980722833988499408662515740, 3043464350691093936525126627], [-855662540010905613357853305805196, -24278055688906892183274781455], [1256321610218034062993116115933480, 22476672383254541743055771970], [1067277009657652939149892306913890, 11464040640266000999677186740], [-96578761364028417407021941710510, 34292642741517215807008246560], [293397993275068970513084163462264, 34919895307815485612013046470], [-3721865775564195447881400789171040, 13286117313777619624908215880], [1939905738047015999521156242420012, 23372341383050822767638470295], [2314989109365982481085741245562244, 27389117021863174293641902245], [-3580885068310740480416005635997200, 973132047750240375008230476], [3912164868970401549149825715978610, -14680832603791207373016886620], [1122660021676295597410222690014018, -21444508787214628645213788000], [-3172436674701264060487772028260760, 14309882949349437999041380818], [7748339094589632399732395689320554, 8136020684709318792594426120], [-4698618408057197514502424219801310, 12966372791626301838846783972], [2993721899973464509683474002585148, -25793903928662643939465966645], [3578445853851605931903686226089338, -222800424053434901259934860], [-2239525282038886499573731789621100, 28025414628333718184113934457], [5177424948163929513118823209529130, -14182651440890105769970018524], [-1426578485443773193881768391290790, 53577261295765129641517701840], [5025981953609196942716308446738560, 50786743639985107506038268576], [-4642434725080694846069784082268340, -30149147621495885879897026209], [-4024148098923118652280895739320694, 64350297828020243763650051460], [5371924668272286728053657951994770, -53339865917805075730716403740], [-446099070573649923991767361118430, 99829850457336519500733466824], [3227846853095320673888142435331756, -1347089310949461517619505225], [4419448958034834704540597559153474, 10444404317194349167000144740], [-9129146917467368877378576116522598, 34184301185278322444182123080], [1106100996402724425932825003707060, 65627134680836557407748430241], [-10263515327516771921255300780743350, -35322209393206877343231521724], [2486662794048943839740958397144738, -54869503874913034858045982700], [17786447062269886134114214021075900, 16008125444135215204718063691], [8114718071680392771068495281211450, 53870508583852574971821359592], [3238862952731334634262497653521504, 19745516293242610303068095160], [-3013886267455589891338855065766990, 73694525257393131201683021856], [-3981984704578769843605653657104680, -22496921175774704599294028226], [-981488089509510483930542903426700, 14275213808136355919016840369], [-9890955676730589602924244274299470, 24191755596163000415480021460], [11972375753991220862581234154326058, -61373723201656515971081618040], [-24404290777934775677530302348668292, 41913801280895748464598268155], [-786434081615198111510444268701280, 206808792796846893406876684296], [-22141743494387159127881017636429624, -54090265193514461770105121910], [-7209425531277036951339607721217000, 189205831018714635507256868814], [-14939329294210619272361180047209782, -85127526661722182645396486220], [-24205368029060904211460051289797660, -11603184340901698214950169763], [-6050216646505253992388794090986096, -170867051804034764949307620780], [-11075402579279626640912051509176430, -78037422011259310827125615448], [-14757917274711662628161829880850310, 80546213527373402956245318180], [9929531143623685839954448447377080, -65121008879949908726236286250], [7337705244518785522223104430838498, 211991961547903772749089935520], [16458575058512751107971555481069442, -28748635576553826328418823420], [20460905280426438664673535191169180, 143501805281222543029754194851], [-31079535335199549566744180337780390, -17673522381777699507546807864], [-33651795864821791561005841665715548, -16619665768824015718462422675], [21101971721522464239949550614424290, 185137004739580571688613289028], [5869899771577051897636573937030802, 157033480571510222818907479860], [15354736150784657594808877892760608, -48603615127172053669024447320], [-21776558589274508051103712876777830, 322673773946154831794180720436], [-21652472558938443952242389601380940, 193073969235061454415124874625], [4242805178427927202215379094280460, -399565818331084700392810324113], [-27525573381663378118853878339396630, -66041957320662545698176480240], [-26666252682260445437202380844156510, -126909091996835608492001512812], [46412967303790386174594335309725712, -341359001381712928911569801100], [-14753881771682671088652749021577540, 154220296130302520655077053611], [67557862478000586579362944781504788, -64902392585824739416257401415], [-35779766611375762280743534369859230, -147526116093334817204689268856], [-6304342985838133217896481239561020, 730165338898105512761963926293], [4594780301451651434083377928502530, -181648193577073774976148534540], [3906348568150043765613339391673304, 337961237916384988341874284990], [27087938439241150840001765502078730, 303915671865705630519718830756], [-27452461276399588942385388632871600, -703502574084278827686555934332], [168365498079729352677230506036410, 137105587435213167486713281620], [-35929635040802985320852017588265310, -776024373100665686435036056440], [-18490382812980633155794477036935380, -37909943106223813915606473321], [-109551875766827304515635499359496760, 67387312839916372692191052810], [-41613516899818611816249632529728566, 700885880663999767566281659080], [-27035194630225889830157619911670564, -428848805656958172553090682925], [-28535396472211365537174781532330688, -856684192578811602877044697200], [21104083061224178575249463988702530, 293657228915497464046386834432], [56051080405944066893128928446984338, 323073423677728796292914725440], [97653336071641398495006009166953532, -52537127066827154876682886005], [112353790269874310789925189034152890, -3728409814190586809125117296], [8432206718961165074805691482985170, 426878434291941206611827389220], [121263303471048979455102974069926880, 33862270301667735453316581912], [38895407347797581284732403488912650, 317944358668974795632788135440], [60470748088859579225645762778775346, -164862834811586648138551921560], [2948471057998815874681538149545292, 226922445784238134376137849695], [117091506783076898468317589772150100, 299583290920743859282721142345], [-192798616358508626114856572368508640, -259378016078378628662446971288], [34895460002512421591024367978499050, -360462426277748628294231489132], [89882709003650899596603583846945090, -380334955854962879080103964780], [-28367328230432887823656103007890190, 1083336955839918547619610691716], [21994236929347117384314890170589120, 505692257863672893288397909680], [-89304969772536768448556898962721780, 922843576815743862140409535599], [-150968932896114993254014217881242524, -867428040194081161799288505795], [-198383241841905327981106126684390380, -1001305801625777201476866157863], [95105950764483905395137251276525650, -870415624790783556610016835900], [-99620815916367748918700811994254750, -1817842866508026785295979338720], [-219233662085102298907163374511287414, 78984507132236170194913938600], [-27022200628837004777320098789985360, 383484267731968253367115062204], [123007115832381527760826544050923610, 213397103998897251783199893396], [-105611373908548414397472130156079910, 1222971325928245985577838247184], [32160021307182208244238623715060234, -467112011195287386523355253660], [44132144292516760557157549262018600, 1173339222922151490411073017090], [-100979504294567318956697668225360110, -2205266784768403421159851185036], [-346175088216532279330596515732082132, 562624942203694645627597996215], [-276748398812051116954704682736944790, 897217049072916923365266503220], [194601329377607806701712176669695620, -362912526156983010942047741883], [-104763465944903990445909575535845136, 1270746147339369120753030290700], [-10135473009264667491040949708093670, 2478048245134208301879143013684], [-97796011256777802831277723921350260, 71145430230211383919679274735], [-82253151178577339646591399613895830, 1390679732025707182910089933968], [-96674265093974133116878787314433502, 2674199864677038524037871997460], [-301847870142105102861588505402871920, 1214122941429844171511536388244], [-326032015711675439475102389316049286, -38265647944275358598895402060], [-459031827775575885576189163136111430, 583764341118242807610693354984], [64418563673811688776360861477265632, -519926050259419547668369758120], [-38088695909974830267851016399608508, -673050129175281362328448878315], [-102321730366294903523597802801597390, 925657770017839657322976596904], [383501313085559561501510265206350680, -1352392964243090047572663449442], [102751198004069777822166938367653770, -4545007327550166198061054245948], [281541612895650166254099338689186986, 2173149159239596650645455331720], [207471591012477553442125053857119440, -1091560057047094779452343633948], [262748732564389515254148566330806356, 3710857946563601866097733847785], [-56090169330847733394773284345696340, -4281622263990184243070755819305], [-71302842071430788358189246827783350, -4958436891053104667596509682392], [671440744282839997287305239446948930, 175225042714804773889085596500], [-116085299596715591663740613045119000, 4479854485312387484279807884722], [635178274368326863288413605697471290, 1218948318222614034679018544400], [248252776325359935542620752284388972, -1663344942613063008701225949465], [51002582734870470646028757001192132, 3911656601602599302707182847125], [564848561252461466168513394717190320, 2359558223456303048394315111036], [-370866454824004077619898688175453350, 1366928837872251889896382342020], [-377296772824083088422335408572985896, 1387896623293232895723972123390], [267195944143028543240689055185516210, 6984757330543713701201331114180], [-502511439887931891397514098511907972, 459997799316634719361804891995], [282293698135278178622669416048842912, -110740627091187131277169654200], [-617332009528175795656929432106181470, 3546913071351689387189592916608], [715451232800112576284284562905502706, -561196593615153963961100520600], [390641990095298148614143417354823450, -65986342634141520205958285616], [68620916591559479426581461878955378, 587453547006061388371656310980], [591554760758802676623372619418108010, -8063543755071388103133389806896], [163780953152254748169027944375209400, 4401074346407438372580538219158], [-891463679608410378611973985386094110, -2133200454846081009990999460224], [710664671732654493746760709390531564, 527509370282573370785844172455], [-449211710813069407307605934668114680, 3283889985413920902372189065562], [-536532728597485601516289735081262288, -4534251170879618811527999454180], [-546225213287817764316751707397900070, 2149097513561205961535367223140], [-27317213515583692441336666069127180, 5265200472160371159405019965489], [-1181325624222053639525228371676361600, 344450152497190324272287660064], [-502229732910076909507979726951674750, -7493164287025387200169072727520], [-1202913606598460892389078711512186230, -5948644827247257898985112877404], [-275690420010250012029196823080533084, 1769710256147603253408790096365], [-801778848288769881178195370199805700, 8297280007761516707224699335675], [-520794077051330692312998318936345864, 7198129999665664141851651147750], [154060972334079855104709288659745530, -2395489261470730911626506278192], [-1065873464032815746870588375920053472, 4155968596365581146295812286760], [1762151291763035512416606499238702154, -4131133628749648840547892684720], [39253103917241930025003963588843268, 1090498194558785838684349160325], [-408329535921027640883595927080577126, 10932783236862285514545802221060], [1061564698134480484361540734746311410, 3222241637713320891034376924580], [639201669847823956454612789440343490, -2135392770779010456202758449400], [-206522659527752189000589777559798000, 19042662232663792226840745573876], [-914291271386690631730335745411606470, 2177234733248501029215898018896], [-1326573994021488671142378309663887190, -5019198847586162243694689892300], [-1898253194346740310280180726946529400, 3052034516108938994442057060090], [-972237524400212178990634202645996030, -13768756125354864872460527885100], [-2019042942467873946459099205453261902, 1884692245537055313712861428840], [1227901902559152172589309390770321180, 2170933200751198017112486470819], [1508489490193577045596047461985786060, -6506827151196789279337450454625], [-37221665070627575145215541264430510, 9489244364699143716455176224288], [927856932138572848337722877810091450, -7637473053541233531788959322556], [-26922681293145390691021970235041580, -19505866171075242452071734533559], [-1875341446674747042211530398897698772, -10703517049363204658180311883145], [-1279927730919513675423155896660301110, -16814678166969126003792120669912], [-1069527459896702956784256970960145214, 19638856551514329404929143610260], [-404443140904083844205069946729315264, -3140349808647869252040860600880], [1719029409654171315326833586463741800, -3179881816515307694261448077166], [-1633420188258919084204444876693304430, -5417500398833453404375476831000], [1443504689123159199265066126241563320, 19295548738674995003110648480662], [-1281633935315330409291654646625690670, 11623838475315714152600059590900], [163165906548093523527575753664521770, -20439370756047924165350331372924], [1248761253836046521414585856450803760, -23790512848825164512538478628772], [-1085664652020336022980648878144525580, 12731724230874850517877032095665], [-1408862913549266459962797226337656150, -2535490837109539388125745962992], [-2804365510417844585560672182161998110, 753587420665362486955139226804], [2374837176085538201711014721926503420, 15220984893654034658087111288091], [557531038083044466611827349554406394, -14625811235541674152289759078520], [1115888082382177791945025172105680468, -13732530205097556085094415226935], [2063331889436577373269741569087271576, 19921041613077005074166386085550]]
